@@ -270,7 +270,7 @@ let break_new_line state (before, offset, after) width =
   state.pp_is_new_line <- true;
   let indent = state.pp_margin - width + offset in
   (* Don't indent more than pp_max_indent. *)
-  let real_indent = min state.pp_max_indent indent in
+  let real_indent = Int.min state.pp_max_indent indent in
   state.pp_current_indent <- real_indent;
   state.pp_space_left <- state.pp_margin - state.pp_current_indent;
   pp_output_indent state state.pp_current_indent;
@@ -636,6 +636,8 @@ let pp_print_as state isize s =
 let pp_print_string state s =
   pp_print_as state (String.length s) s
 
+let pp_print_bytes state s =
+  pp_print_as state (Bytes.length s) (Bytes.to_string s)
 
 (* To format an integer. *)
 let pp_print_int state i = pp_print_string state (Int.to_string i)
@@ -806,7 +808,7 @@ let pp_set_margin state n =
       (* If possible maintain pp_min_space_left to its actual value,
          if this leads to a too small max_indent, take half of the
          new margin, if it is greater than 1. *)
-       max (max (state.pp_margin - state.pp_min_space_left)
+       Int.max (Int.max (state.pp_margin - state.pp_min_space_left)
                 (state.pp_margin / 2)) 1 in
     (* Rebuild invariants. *)
     pp_set_max_indent state new_max_indent
@@ -1114,6 +1116,7 @@ and open_stag = pp_open_stag std_formatter
 and close_stag = pp_close_stag std_formatter
 and print_as = pp_print_as std_formatter
 and print_string = pp_print_string std_formatter
+and print_bytes = pp_print_bytes std_formatter
 and print_int = pp_print_int std_formatter
 and print_float = pp_print_float std_formatter
 and print_char = pp_print_char std_formatter
@@ -1237,6 +1240,10 @@ let pp_print_result ~ok ~error ppf = function
 | Ok v -> ok ppf v
 | Error e -> error ppf e
 
+let pp_print_either ~left ~right ppf = function
+| Either.Left l -> left ppf l
+| Either.Right r -> right ppf r
+
  (**************************************************************)
 
 let compute_tag output tag_acc =
