@@ -55,7 +55,6 @@ external make_forward : 'a -> 'a lazy_t = "caml_lazy_make_forward"
 
 external force : 'a t -> 'a = "%lazy_force"
 
-(* let force = force *)
 
 let force_val = CamlinternalLazy.force_val
 
@@ -64,7 +63,6 @@ let from_fun (f : unit -> 'arg) =
   Obj.set_field x 0 (Obj.repr f);
   (Obj.obj x : 'arg t)
 
-
 let from_val (v : 'arg) =
   let t = Obj.tag (Obj.repr v) in
   if t = Obj.forward_tag || t = Obj.lazy_tag || t = Obj.double_tag then begin
@@ -81,3 +79,12 @@ let lazy_from_fun = from_fun
 let lazy_from_val = from_val
 
 let lazy_is_val = is_val
+
+
+let map f x =
+  lazy (f (force x))
+
+let map_val f x =
+  if is_val x
+  then lazy_from_val (f (force x))
+  else lazy (f (force x))
